==> ejc-sale-impl-3.0.0-20220404.055637-20-sources.jar: com/ejianc/business/sale/vo/PaymentdetialVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 付款管理子表
 * 
 * @author generator
 * 
 */
public class PaymentdetialVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long mid; // 
    private Date consignmentDate; // 发货年月
    private BigDecimal paymentMoney; // 应付金额
    private BigDecimal paidMoney; // 本单已付金额
    private BigDecimal otherPaidMoney; // 其他单已付金额
    private BigDecimal outstandingMoney; // 未付金额
    private BigDecimal distributionMoney; // 分配金额
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public Date getConsignmentDate() {
        return consignmentDate;
    }

    public void setConsignmentDate(Date consignmentDate) {
        this.consignmentDate = consignmentDate;
    }
    public BigDecimal getPaymentMoney() {
        return paymentMoney;
    }

    public void setPaymentMoney(BigDecimal paymentMoney) {
        this.paymentMoney = paymentMoney;
    }
    public BigDecimal getPaidMoney() {
        return paidMoney;
    }

    public void setPaidMoney(BigDecimal paidMoney) {
        this.paidMoney = paidMoney;
    }
    public BigDecimal getOtherPaidMoney() {
        return otherPaidMoney;
    }

    public void setOtherPaidMoney(BigDecimal otherPaidMoney) {
        this.otherPaidMoney = otherPaidMoney;
    }
    public BigDecimal getOutstandingMoney() {
        return outstandingMoney;
    }

    public void setOutstandingMoney(BigDecimal outstandingMoney) {
        this.outstandingMoney = outstandingMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-sale-impl-3.0.0-20220818.035037-208-sources.jar: com/ejianc/business/sale/vo/PaymentdetialVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 付款管理子表
 * 
 * @author generator
 * 
 */
public class PaymentdetialVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long mid; //
    private String billCode; // 单据编号
    private Date consignmentDate; // 发货年月
    private BigDecimal paymentMoney; // 应付金额
    private BigDecimal paidMoney; // 本单已付金额
    private BigDecimal otherPaidMoney; // 其他单已付金额
    private BigDecimal outstandingMoney; // 未付金额
    private BigDecimal distributionMoney; // 分配金额
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long manualshipmentId; //发货单id

    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Date getConsignmentDate() {
        return consignmentDate;
    }

    public void setConsignmentDate(Date consignmentDate) {
        this.consignmentDate = consignmentDate;
    }
    public BigDecimal getPaymentMoney() {
        return paymentMoney;
    }

    public void setPaymentMoney(BigDecimal paymentMoney) {
        this.paymentMoney = paymentMoney;
    }
    public BigDecimal getPaidMoney() {
        return paidMoney;
    }

    public void setPaidMoney(BigDecimal paidMoney) {
        this.paidMoney = paidMoney;
    }
    public BigDecimal getOtherPaidMoney() {
        return otherPaidMoney;
    }

    public void setOtherPaidMoney(BigDecimal otherPaidMoney) {
        this.otherPaidMoney = otherPaidMoney;
    }
    public BigDecimal getOutstandingMoney() {
        return outstandingMoney;
    }

    public void setOutstandingMoney(BigDecimal outstandingMoney) {
        this.outstandingMoney = outstandingMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getManualshipmentId() {
        return manualshipmentId;
    }

    public void setManualshipmentId(Long manualshipmentId) {
        this.manualshipmentId = manualshipmentId;
    }
}
